<!--
SPDX-FileCopyrightText: 2021 The eminus developers
SPDX-License-Identifier: Apache-2.0
-->
# tests

Unit tests to ensure the code is performing correctly.

| Folder           | Description |
| :--------------: | :---------: |
| dft_calculations | Test DFT calculations |
| examples         | Test examples execution |
| extras           | Test extra functionalities |

The tests can be run with your Python interpreter or using [pytest](https://docs.pytest.org).

pytest can be installed with

```terminal
pip install pytest
```

Running all tests can be simply performed with

```terminal
pytest
```

Some examples may need Jupyter and/or some extras to be installed.

Jupyter can be installed with

```terminal
pip install notebook
```

Information about installing extras can be found [here](https://wangenau.gitlab.io/eminus/_autosummary/eminus.extras.html#module-eminus.extras).
